public/audio_listener library
Classes
- AudioListener
-
The interface represents the position and orientation of the
unique person listening to the audio scene, and is used in audio
spatialization. All
PannerNodes spatialize in relation to the stored in theBaseAudioContext.listenerattribute. It is important to note that there is only one listener per context and that it isn't an AudioNode.